@@ -12,13 +12,15 @@
 use std::borrow::Cow;
 
 use serde::{Deserialize, Serialize};
+#[cfg(feature = "validation")]
 use validator::Validate;
 
+#[cfg(feature = "validation")]
+use crate::val_helpr::ValidationResult;
 use crate::{compose,
             compose::{opt::NoUrl, Confirm},
             elems::select::external::build,
-            text,
-            val_helpr::ValidationResult};
+            text};
 
 type OptOrOptGroup<'a> = compose::OptOrOptGroup<'a, text::Plain, NoUrl>;
 
@@ -32,26 +34,28 @@ type OptOrOptGroup<'a> = compose::OptOrOptGroup<'a, text::Plain, NoUrl>;
 /// [Slack API doc guide for setting up an external data source 🔗](https://api.slack.com/reference/block-kit/block-elements#external_select__setup)
 ///
 /// [slack api docs 🔗]: https://api.slack.com/reference/block-kit/block-elements#external_select
-#[derive(Clone, Debug, Deserialize, Hash, PartialEq, Serialize, Validate)]
+#[derive(Clone, Debug, Deserialize, Hash, PartialEq, Serialize)]
+#[cfg_attr(feature = "validation", derive(Validate))]
 pub struct External<'a> {
-  #[validate(custom = "crate::elems::select::validate::placeholder")]
+  #[cfg_attr(feature = "validation",
+             validate(custom = "crate::elems::select::validate::placeholder"))]
   pub(in crate::elems::select) placeholder: text::Text,
 
-  #[validate(length(max = 255))]
+  #[cfg_attr(feature = "validation", validate(length(max = 255)))]
   pub(in crate::elems::select) action_id: Cow<'a, str>,
 
   #[serde(skip_serializing_if = "Option::is_none")]
   pub(in crate::elems::select) min_query_length: Option<u64>,
 
   #[serde(skip_serializing_if = "Option::is_none")]
-  #[validate]
+  #[cfg_attr(feature = "validation", validate)]
   pub(in crate::elems::select) confirm: Option<Confirm>,
 
   #[serde(skip_serializing_if = "Option::is_none")]
   pub(in crate::elems::select) initial_options:
     Option<Cow<'a, [OptOrOptGroup<'a>]>>,
 
-  #[validate(range(min = 1))]
+  #[cfg_attr(feature = "validation", validate(range(min = 1)))]
   #[serde(skip_serializing_if = "Option::is_none")]
   pub(in crate::elems::select) max_selected_items: Option<u32>,
 }
@@ -70,10 +74,8 @@ impl<'a> External<'a> {
   /// Validate that this user select agrees with Slack's model requirements
   ///
   /// # Errors
-  /// - If `from_placeholder_and_action_id` was called with
-  ///     `placeholder` longer than 150 chars
-  /// - If `from_placeholder_and_action_id` was called with
-  ///     `action_id` longer than 255 chars
+  /// - If `placeholder` longer than 150 chars
+  /// - If `action_id` longer than 255 chars
   ///
   /// # Example
   /// ```
@@ -92,6 +94,8 @@ impl<'a> External<'a> {
   ///
   /// assert!(matches!(select.validate(), Err(_)))
   /// ```
+  #[cfg(feature = "validation")]
+  #[cfg_attr(docsrs, doc(cfg(feature = "validation")))]
   pub fn validate(&self) -> ValidationResult {
     Validate::validate(self)
   }
