@@ -72,7 +72,9 @@
 //! [issues]: https://github.com/cakekindel/slack-blocks-rs/issues/
 //! [Conventional Commits]: https://www.conventionalcommits.org/en/v1.0.0/
 
+#![doc(html_root_url = "https://docs.rs/slack-blocks/0.24.1")]
 #![cfg_attr(docsrs, feature(doc_cfg))]
+#![cfg_attr(docsrs, feature(intra_rustdoc_links))]
 #![deny(missing_docs)]
 #![cfg_attr(not(test),
             forbid(missing_copy_implementations,
